// THIS FILE IS GENERATED. ONE SHOULD NOT MODIFY IT
//! This module provides terms for `dtype` vocabulary
//!
//! This module requires `ns-dtype` feature to be enabled.
//!
//! ## Vocabulary:
//!
//! |||
//! |-----|-----|
//! |**Title**||
//! |**Prefix**|dtype|
//! |**Namespace base IRI**|<http://www.linkedmodel.org/schema/dtype#>|
//! |**Description**||
//! |**Is defined by**|<http://www.linkedmodel.org/schema/dtype#>|
//!

use crate::namespace;

namespace!(
    "http://www.linkedmodel.org/schema/dtype#",;
    /// ``: 
    NAMESPACE_BASE, "",
    /// `Codelist`: 
    CodeList, "CodeList",
    /// `Composite Code List`: 
    CompositeCodeList, "CompositeCodeList",
    /// `Derived Code List`: 
    DerivedCodeList, "DerivedCodeList",
    /// `DTYPE Enumerated value`: 
    EnumeratedValue, "EnumeratedValue",
    /// `DTYPE Enumeration`: 
    Enumeration, "Enumeration",
    /// `Simple Code List`: 
    SimpleCodeList, "SimpleCodeList",
    /// `Value Reference`: 
    ValueReference, "ValueReference",
    /// `code`: 
    code, "code",
    /// `composite of`: 
    compositeOf, "compositeOf",
    /// `default value`: 
    defaultValue, "defaultValue",
    /// `derived from`: 
    derivedFrom, "derivedFrom",
    /// `has member`: 
    hasMember, "hasMember",
    /// `is invalid`: 
    isInvalid, "isInvalid",
    /// `literal`: 
    literal, "literal",
    /// `numeric union`: 
    numericUnion, "numericUnion",
    /// `order`: 
    order, "order",
    /// `order index`: 
    orderIndex, "orderIndex",
    /// `position`: 
    position, "position",
    /// `refers to`: 
    refersTo, "refersTo",
    /// `datatype`: 
    type_, "type",
    /// `value`: 
    value, "value"
);
